summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorXuchen Han <xuchenhan@xuchenhan-macbookpro.roam.corp.google.com>2019-08-08 15:00:55 -0700
committerXuchen Han <xuchenhan@xuchenhan-macbookpro.roam.corp.google.com>2019-08-08 15:00:55 -0700
commit9a7e30d09ffe20a533ad76b1729e66232aa5de89 (patch)
treedf238101e82e9cdb363c5dec21c5e82c7c98ead3
parent02c5b99b2f894252205b39bc46405c7a3b9a2084 (diff)
downloadbullet3-9a7e30d09ffe20a533ad76b1729e66232aa5de89.tar.gz
move deformable examples to a single folder and rename them; change license to google 2016
-rw-r--r--examples/CMakeLists.txt2
-rw-r--r--examples/DeformableContact/DeformableContact.h20
-rw-r--r--examples/DeformableDemo/DeformableDemo.h20
-rw-r--r--examples/DeformableDemo/DeformableMultibody.cpp (renamed from examples/DeformableContact/DeformableContact.cpp)48
-rw-r--r--examples/DeformableDemo/DeformableMultibody.h19
-rw-r--r--examples/DeformableDemo/DeformableRigid.cpp (renamed from examples/DeformableDemo/DeformableDemo.cpp)42
-rw-r--r--examples/DeformableDemo/DeformableRigid.h19
-rw-r--r--examples/DeformableDemo/Pinch.cpp (renamed from examples/Pinch/Pinch.cpp)24
-rw-r--r--examples/DeformableDemo/Pinch.h19
-rw-r--r--examples/DeformableDemo/VolumetricDeformable.cpp (renamed from examples/VolumetricDeformable/VolumetricDeformable.cpp)24
-rw-r--r--examples/DeformableDemo/VolumetricDeformable.h19
-rw-r--r--examples/ExampleBrowser/CMakeLists.txt16
-rw-r--r--examples/ExampleBrowser/ExampleEntries.cpp13
-rw-r--r--examples/ExampleBrowser/premake4.lua3
-rw-r--r--examples/Pinch/Pinch.h20
-rw-r--r--examples/VolumetricDeformable/VolumetricDeformable.h20
-rw-r--r--src/BulletSoftBody/btDeformableRigidDynamicsWorld.h4
17 files changed, 157 insertions, 175 deletions
diff --git a/examples/CMakeLists.txt b/examples/CMakeLists.txt
index 1918a9003..ba9efac19 100644
--- a/examples/CMakeLists.txt
+++ b/examples/CMakeLists.txt
@@ -1,4 +1,4 @@
-SUBDIRS( HelloWorld BasicDemo )
+SUBDIRS( HelloWorld BasicDemo)
IF(BUILD_BULLET3)
SUBDIRS( ExampleBrowser RobotSimulator SharedMemory ThirdPartyLibs/Gwen ThirdPartyLibs/BussIK ThirdPartyLibs/clsocket OpenGLWindow TwoJoint )
ENDIF()
diff --git a/examples/DeformableContact/DeformableContact.h b/examples/DeformableContact/DeformableContact.h
deleted file mode 100644
index 591c6bab1..000000000
--- a/examples/DeformableContact/DeformableContact.h
+++ /dev/null
@@ -1,20 +0,0 @@
-/*
-Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans http://continuousphysics.com/Bullet/
-
-This software is provided 'as-is', without any express or implied warranty.
-In no event will the authors be held liable for any damages arising from the use of this software.
-Permission is granted to anyone to use this software for any purpose,
-including commercial applications, and to alter it and redistribute it freely,
-subject to the following restrictions:
-
-1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
-2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
-3. This notice may not be removed or altered from any source distribution.
-*/
-#ifndef _DEFORMABLE_CONTACT_H
-#define _DEFORMABLE_CONTACT_H
-
-class CommonExampleInterface* DeformableContactCreateFunc(struct CommonExampleOptions& options);
-
-#endif //_DEFORMABLE_CONTACT_H
diff --git a/examples/DeformableDemo/DeformableDemo.h b/examples/DeformableDemo/DeformableDemo.h
deleted file mode 100644
index c688cea9d..000000000
--- a/examples/DeformableDemo/DeformableDemo.h
+++ /dev/null
@@ -1,20 +0,0 @@
-/*
-Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans http://continuousphysics.com/Bullet/
-
-This software is provided 'as-is', without any express or implied warranty.
-In no event will the authors be held liable for any damages arising from the use of this software.
-Permission is granted to anyone to use this software for any purpose,
-including commercial applications, and to alter it and redistribute it freely,
-subject to the following restrictions:
-
-1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
-2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
-3. This notice may not be removed or altered from any source distribution.
-*/
-#ifndef _DEFORMABLE_DEMO_H
-#define _DEFORMABLE_DEMO_H
-
-class CommonExampleInterface* DeformableCreateFunc(struct CommonExampleOptions& options);
-
-#endif //_DEFORMABLE_DEMO_H
diff --git a/examples/DeformableDemo/DeformableMultibody.h b/examples/DeformableDemo/DeformableMultibody.h
new file mode 100644
index 000000000..8bc9020f3
--- /dev/null
+++ b/examples/DeformableDemo/DeformableMultibody.h
@@ -0,0 +1,19 @@
+/*
+ Bullet Continuous Collision Detection and Physics Library
+ Copyright (c) 2016 Google Inc. http://bulletphysics.org
+ This software is provided 'as-is', without any express or implied warranty.
+ In no event will the authors be held liable for any damages arising from the use of this software.
+ Permission is granted to anyone to use this software for any purpose,
+ including commercial applications, and to alter it and redistribute it freely,
+ subject to the following restrictions:
+ 1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
+ 2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
+ 3. This notice may not be removed or altered from any source distribution.
+ */
+
+#ifndef _DEFORMABLE_MULTIBODY_H
+#define _DEFORMABLE_MULTIBODY_H
+
+class CommonExampleInterface* DeformableMultibodyCreateFunc(struct CommonExampleOptions& options);
+
+#endif //_DEFORMABLE_MULTIBODY_H
diff --git a/examples/DeformableDemo/DeformableRigid.h b/examples/DeformableDemo/DeformableRigid.h
new file mode 100644
index 000000000..1f2bb0911
--- /dev/null
+++ b/examples/DeformableDemo/DeformableRigid.h
@@ -0,0 +1,19 @@
+/*
+ Bullet Continuous Collision Detection and Physics Library
+ Copyright (c) 2016 Google Inc. http://bulletphysics.org
+ This software is provided 'as-is', without any express or implied warranty.
+ In no event will the authors be held liable for any damages arising from the use of this software.
+ Permission is granted to anyone to use this software for any purpose,
+ including commercial applications, and to alter it and redistribute it freely,
+ subject to the following restrictions:
+ 1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
+ 2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
+ 3. This notice may not be removed or altered from any source distribution.
+ */
+
+#ifndef _DEFORMABLE_RIGID_H
+#define _DEFORMABLE_RIGID_H
+
+class CommonExampleInterface* DeformableRigidCreateFunc(struct CommonExampleOptions& options);
+
+#endif //_DEFORMABLE_RIGID_H
diff --git a/examples/Pinch/Pinch.cpp b/examples/DeformableDemo/Pinch.cpp
index c6e26ddb1..aaae1df3f 100644
--- a/examples/Pinch/Pinch.cpp
+++ b/examples/DeformableDemo/Pinch.cpp
@@ -1,17 +1,15 @@
/*
-Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans http://continuousphysics.com/Bullet/
-
-This software is provided 'as-is', without any express or implied warranty.
-In no event will the authors be held liable for any damages arising from the use of this software.
-Permission is granted to anyone to use this software for any purpose,
-including commercial applications, and to alter it and redistribute it freely,
-subject to the following restrictions:
-
-1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
-2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
-3. This notice may not be removed or altered from any source distribution.
-*/
+ Bullet Continuous Collision Detection and Physics Library
+ Copyright (c) 2016 Google Inc. http://bulletphysics.org
+ This software is provided 'as-is', without any express or implied warranty.
+ In no event will the authors be held liable for any damages arising from the use of this software.
+ Permission is granted to anyone to use this software for any purpose,
+ including commercial applications, and to alter it and redistribute it freely,
+ subject to the following restrictions:
+ 1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
+ 2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
+ 3. This notice may not be removed or altered from any source distribution.
+ */
///create 125 (5x5x5) dynamic object
#define ARRAY_SIZE_X 5
diff --git a/examples/DeformableDemo/Pinch.h b/examples/DeformableDemo/Pinch.h
new file mode 100644
index 000000000..3d01b262f
--- /dev/null
+++ b/examples/DeformableDemo/Pinch.h
@@ -0,0 +1,19 @@
+/*
+ Bullet Continuous Collision Detection and Physics Library
+ Copyright (c) 2016 Google Inc. http://bulletphysics.org
+ This software is provided 'as-is', without any express or implied warranty.
+ In no event will the authors be held liable for any damages arising from the use of this software.
+ Permission is granted to anyone to use this software for any purpose,
+ including commercial applications, and to alter it and redistribute it freely,
+ subject to the following restrictions:
+ 1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
+ 2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
+ 3. This notice may not be removed or altered from any source distribution.
+ */
+
+#ifndef _PINCH_H
+#define _PINCH_H
+
+class CommonExampleInterface* PinchCreateFunc(struct CommonExampleOptions& options);
+
+#endif //_PINCH_H
diff --git a/examples/VolumetricDeformable/VolumetricDeformable.cpp b/examples/DeformableDemo/VolumetricDeformable.cpp
index b30e4ac4d..6f2b88f8d 100644
--- a/examples/VolumetricDeformable/VolumetricDeformable.cpp
+++ b/examples/DeformableDemo/VolumetricDeformable.cpp
@@ -1,17 +1,15 @@
/*
-Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans http://continuousphysics.com/Bullet/
-
-This software is provided 'as-is', without any express or implied warranty.
-In no event will the authors be held liable for any damages arising from the use of this software.
-Permission is granted to anyone to use this software for any purpose,
-including commercial applications, and to alter it and redistribute it freely,
-subject to the following restrictions:
-
-1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
-2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
-3. This notice may not be removed or altered from any source distribution.
-*/
+ Bullet Continuous Collision Detection and Physics Library
+ Copyright (c) 2016 Google Inc. http://bulletphysics.org
+ This software is provided 'as-is', without any express or implied warranty.
+ In no event will the authors be held liable for any damages arising from the use of this software.
+ Permission is granted to anyone to use this software for any purpose,
+ including commercial applications, and to alter it and redistribute it freely,
+ subject to the following restrictions:
+ 1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
+ 2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
+ 3. This notice may not be removed or altered from any source distribution.
+ */
///create 125 (5x5x5) dynamic object
#define ARRAY_SIZE_X 5
diff --git a/examples/DeformableDemo/VolumetricDeformable.h b/examples/DeformableDemo/VolumetricDeformable.h
new file mode 100644
index 000000000..04e30d9c6
--- /dev/null
+++ b/examples/DeformableDemo/VolumetricDeformable.h
@@ -0,0 +1,19 @@
+/*
+ Bullet Continuous Collision Detection and Physics Library
+ Copyright (c) 2016 Google Inc. http://bulletphysics.org
+ This software is provided 'as-is', without any express or implied warranty.
+ In no event will the authors be held liable for any damages arising from the use of this software.
+ Permission is granted to anyone to use this software for any purpose,
+ including commercial applications, and to alter it and redistribute it freely,
+ subject to the following restrictions:
+ 1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
+ 2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
+ 3. This notice may not be removed or altered from any source distribution.
+ */
+
+#ifndef _VOLUMETRIC_DEFORMABLE_H
+#define _VOLUMETRIC_DEFORMABLE_H
+
+class CommonExampleInterface* VolumetricDeformableCreateFunc(struct CommonExampleOptions& options);
+
+#endif //_VOLUMETRIC_DEFORMABLE__H
diff --git a/examples/ExampleBrowser/CMakeLists.txt b/examples/ExampleBrowser/CMakeLists.txt
index cfae5fcc5..19334b2db 100644
--- a/examples/ExampleBrowser/CMakeLists.txt
+++ b/examples/ExampleBrowser/CMakeLists.txt
@@ -359,14 +359,14 @@ SET(BulletExampleBrowser_SRCS
../MultiBody/MultiBodyConstraintFeedback.cpp
../SoftDemo/SoftDemo.cpp
../SoftDemo/SoftDemo.h
- ../Pinch/Pinch.cpp
- ../Pinch/Pinch.h
- ../DeformableContact/DeformableContact.cpp
- ../DeformableContact/DeformableContact.h
- ../DeformableDemo/DeformableDemo.cpp
- ../DeformableDemo/DeformableDemo.h
- ../VolumetricDeformable/VolumetricDeformable.cpp
- ../VolumetricDeformable/VolumetricDeformable.h
+ ../DeformableDemo/Pinch.cpp
+ ../DeformableDemo/Pinch.h
+ ../DeformableDemo/DeformableMultibody.cpp
+ ../DeformableDemo/DeformableMultibody.h
+ ../DeformableDemo/DeformableRigid.cpp
+ ../DeformableDemo/DeformableRigid.h
+ ../DeformableDemo/VolumetricDeformable.cpp
+ ../DeformableDemo/VolumetricDeformable.h
../MultiBody/MultiDofDemo.cpp
../MultiBody/MultiDofDemo.h
../RigidBody/RigidBodySoftContact.cpp
diff --git a/examples/ExampleBrowser/ExampleEntries.cpp b/examples/ExampleBrowser/ExampleEntries.cpp
index f186f642a..481d36c5d 100644
--- a/examples/ExampleBrowser/ExampleEntries.cpp
+++ b/examples/ExampleBrowser/ExampleEntries.cpp
@@ -47,11 +47,10 @@
#include "../FractureDemo/FractureDemo.h"
#include "../DynamicControlDemo/MotorDemo.h"
#include "../RollingFrictionDemo/RollingFrictionDemo.h"
-#include "../DeformableDemo/DeformableDemo.h"
-#include "../Pinch/Pinch.h"
-#include "../DeformableContact/DeformableContact.h"
-#include "../MultiBodyBaseline/MultiBodyBaseline.h"
-#include "../VolumetricDeformable/VolumetricDeformable.h"
+#include "../DeformableDemo/DeformableRigid.h"
+#include "../DeformableDemo/Pinch.h"
+#include "../DeformableDemo/DeformableMultibody.h"
+#include "../DeformableDemo/VolumetricDeformable.h"
#include "../SharedMemory/PhysicsServerExampleBullet2.h"
#include "../SharedMemory/PhysicsServerExample.h"
#include "../SharedMemory/PhysicsClientExample.h"
@@ -196,10 +195,10 @@ static ExampleEntry gDefaultExamples[] =
//ExampleEntry(1, "Spheres & Plane C-API (Bullet3)", "Collision C-API using Bullet 3.x backend", CollisionTutorialBullet2CreateFunc,TUT_SPHERE_PLANE_RTB3),
ExampleEntry(0, "Deformabe Body"),
- ExampleEntry(1, "Deformable-RigidBody Contact", "Deformable test", DeformableCreateFunc),
+ ExampleEntry(1, "Deformable-RigidBody Contact", "Deformable test", DeformableRigidCreateFunc),
ExampleEntry(1, "Grasp Deformable Cube", "Grasping test", PinchCreateFunc),
ExampleEntry(1, "Volumetric Deformable Objects", "Volumetric Deformable test", VolumetricDeformableCreateFunc),
- ExampleEntry(1, "Deformable-MultiBody Contact", "MultiBody and Deformable contact", DeformableContactCreateFunc),
+ ExampleEntry(1, "Deformable-MultiBody Contact", "MultiBody and Deformable contact", DeformableMultibodyCreateFunc),
// ExampleEntry(1, "MultiBody Baseline", "MultiBody Baseline", MultiBodyBaselineCreateFunc),
#ifdef INCLUDE_CLOTH_DEMOS
diff --git a/examples/ExampleBrowser/premake4.lua b/examples/ExampleBrowser/premake4.lua
index ff81b34b7..985a0457b 100644
--- a/examples/ExampleBrowser/premake4.lua
+++ b/examples/ExampleBrowser/premake4.lua
@@ -189,9 +189,6 @@ project "App_BulletExampleBrowser"
"../VoronoiFracture/*",
"../SoftDemo/*",
"../DeformableDemo/*",
- "../DeformableContact/*",
- "../VolumetricDeformable/*",
- "../Pinch/*",
"../RollingFrictionDemo/*",
"../rbdl/*",
"../FractureDemo/*",
diff --git a/examples/Pinch/Pinch.h b/examples/Pinch/Pinch.h
deleted file mode 100644
index 6c7e2fb3c..000000000
--- a/examples/Pinch/Pinch.h
+++ /dev/null
@@ -1,20 +0,0 @@
-/*
-Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans http://continuousphysics.com/Bullet/
-
-This software is provided 'as-is', without any express or implied warranty.
-In no event will the authors be held liable for any damages arising from the use of this software.
-Permission is granted to anyone to use this software for any purpose,
-including commercial applications, and to alter it and redistribute it freely,
-subject to the following restrictions:
-
-1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
-2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
-3. This notice may not be removed or altered from any source distribution.
-*/
-#ifndef _PINCH_H
-#define _PINCH_H
-
-class CommonExampleInterface* PinchCreateFunc(struct CommonExampleOptions& options);
-
-#endif //_PINCH_H
diff --git a/examples/VolumetricDeformable/VolumetricDeformable.h b/examples/VolumetricDeformable/VolumetricDeformable.h
deleted file mode 100644
index af1cc38b6..000000000
--- a/examples/VolumetricDeformable/VolumetricDeformable.h
+++ /dev/null
@@ -1,20 +0,0 @@
-/*
-Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans http://continuousphysics.com/Bullet/
-
-This software is provided 'as-is', without any express or implied warranty.
-In no event will the authors be held liable for any damages arising from the use of this software.
-Permission is granted to anyone to use this software for any purpose,
-including commercial applications, and to alter it and redistribute it freely,
-subject to the following restrictions:
-
-1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
-2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
-3. This notice may not be removed or altered from any source distribution.
-*/
-#ifndef _VOLUMETRIC_DEFORMABLE_H
-#define _VOLUMETRIC_DEFORMABLE_H
-
-class CommonExampleInterface* VolumetricDeformableCreateFunc(struct CommonExampleOptions& options);
-
-#endif //_VOLUMETRIC_DEFORMABLE__H
diff --git a/src/BulletSoftBody/btDeformableRigidDynamicsWorld.h b/src/BulletSoftBody/btDeformableRigidDynamicsWorld.h
index cc4fdae05..6489d6ebc 100644
--- a/src/BulletSoftBody/btDeformableRigidDynamicsWorld.h
+++ b/src/BulletSoftBody/btDeformableRigidDynamicsWorld.h
@@ -1,13 +1,11 @@
/*
Bullet Continuous Collision Detection and Physics Library
- Copyright (c) 2003-2006 Erwin Coumans http://continuousphysics.com/Bullet/
-
+ Copyright (c) 2016 Google Inc. http://bulletphysics.org
This software is provided 'as-is', without any express or implied warranty.
In no event will the authors be held liable for any damages arising from the use of this software.
Permission is granted to anyone to use this software for any purpose,
including commercial applications, and to alter it and redistribute it freely,
subject to the following restrictions:
-
1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
3. This notice may not be removed or altered from any source distribution.
diff --git a/examples/DeformableContact/DeformableContact.cpp b/examples/DeformableDemo/DeformableMultibody.cpp
index 102ad40a9..78adf7bf1 100644
--- a/examples/DeformableContact/DeformableContact.cpp
+++ b/examples/DeformableDemo/DeformableMultibody.cpp
@@ -1,17 +1,15 @@
/*
-Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans http://continuousphysics.com/Bullet/
-
-This software is provided 'as-is', without any express or implied warranty.
-In no event will the authors be held liable for any damages arising from the use of this software.
-Permission is granted to anyone to use this software for any purpose,
-including commercial applications, and to alter it and redistribute it freely,
-subject to the following restrictions:
-
-1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
-2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
-3. This notice may not be removed or altered from any source distribution.
-*/
+ Bullet Continuous Collision Detection and Physics Library
+ Copyright (c) 2016 Google Inc. http://bulletphysics.org
+ This software is provided 'as-is', without any express or implied warranty.
+ In no event will the authors be held liable for any damages arising from the use of this software.
+ Permission is granted to anyone to use this software for any purpose,
+ including commercial applications, and to alter it and redistribute it freely,
+ subject to the following restrictions:
+ 1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
+ 2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
+ 3. This notice may not be removed or altered from any source distribution.
+ */
///create 125 (5x5x5) dynamic object
#define ARRAY_SIZE_X 5
@@ -27,7 +25,7 @@ subject to the following restrictions:
#define START_POS_Y -5
#define START_POS_Z -3
-#include "DeformableContact.h"
+#include "DeformableMultibody.h"
///btBulletDynamicsCommon.h is the main Bullet include file, contains most common include files.
#include "btBulletDynamicsCommon.h"
#include "BulletSoftBody/btDeformableRigidDynamicsWorld.h"
@@ -46,20 +44,20 @@ subject to the following restrictions:
#include "../CommonInterfaces/CommonMultiBodyBase.h"
#include "../Utils/b3ResourcePath.h"
///The DeformableContact demo deformable bodies self-collision
static bool g_floatingBase = true;
static float friction = 1.;
-class DeformableContact : public CommonMultiBodyBase
+class DeformableMultibody : public CommonMultiBodyBase
{
btMultiBody* m_multiBody;
btAlignedObjectArray<btMultiBodyJointFeedback*> m_jointFeedbacks;
public:
- DeformableContact(struct GUIHelperInterface* helper)
+ DeformableMultibody(struct GUIHelperInterface* helper)
: CommonMultiBodyBase(helper)
{
}
- virtual ~DeformableContact()
+ virtual ~DeformableMultibody()
{
}
@@ -109,7 +107,7 @@ public:
}
};
-void DeformableContact::initPhysics()
+void DeformableMultibody::initPhysics()
{
m_guiHelper->setUpAxis(1);
@@ -237,7 +235,7 @@ void DeformableContact::initPhysics()
m_guiHelper->autogenerateGraphicsObjects(m_dynamicsWorld);
}
-void DeformableContact::exitPhysics()
+void DeformableMultibody::exitPhysics()
{
//cleanup in the reverse order of creation/initialization
@@ -274,14 +272,14 @@ void DeformableContact::exitPhysics()
delete m_collisionConfiguration;
}
-void DeformableContact::stepSimulation(float deltaTime)
+void DeformableMultibody::stepSimulation(float deltaTime)
{
// getDeformableDynamicsWorld()->getMultiBodyDynamicsWorld()->stepSimulation(deltaTime);
m_dynamicsWorld->stepSimulation(deltaTime, 5, 1./250.);
}
-btMultiBody* DeformableContact::createFeatherstoneMultiBody_testMultiDof(btMultiBodyDynamicsWorld* pWorld, int numLinks, const btVector3& basePosition, const btVector3& baseHalfExtents, const btVector3& linkHalfExtents, bool spherical, bool floating)
+btMultiBody* DeformableMultibody::createFeatherstoneMultiBody_testMultiDof(btMultiBodyDynamicsWorld* pWorld, int numLinks, const btVector3& basePosition, const btVector3& baseHalfExtents, const btVector3& linkHalfExtents, bool spherical, bool floating)
{
//init the base
btVector3 baseInertiaDiag(0.f, 0.f, 0.f);
@@ -341,7 +339,7 @@ btMultiBody* DeformableContact::createFeatherstoneMultiBody_testMultiDof(btMulti
return pMultiBody;
}
-void DeformableContact::addColliders_testMultiDof(btMultiBody* pMultiBody, btMultiBodyDynamicsWorld* pWorld, const btVector3& baseHalfExtents, const btVector3& linkHalfExtents)
+void DeformableMultibody::addColliders_testMultiDof(btMultiBody* pMultiBody, btMultiBodyDynamicsWorld* pWorld, const btVector3& baseHalfExtents, const btVector3& linkHalfExtents)
{
btAlignedObjectArray<btQuaternion> world_to_local;
world_to_local.resize(pMultiBody->getNumLinks() + 1);
@@ -403,9 +401,9 @@ void DeformableContact::addColliders_testMultiDof(btMultiBody* pMultiBody, btMul
pMultiBody->getLink(i).m_collider = col;
}
}
-class CommonExampleInterface* DeformableContactCreateFunc(struct CommonExampleOptions& options)
+class CommonExampleInterface* DeformableMultibodyCreateFunc(struct CommonExampleOptions& options)
{
- return new DeformableContact(options.m_guiHelper);
+ return new DeformableMultibody(options.m_guiHelper);
}
@@ -46,20 +44,20 @@ subject to the following restrictions:
#include "../CommonInterfaces/CommonMultiBodyBase.h"
#include "../Utils/b3ResourcePath.h"
-///The DeformableContact demo deformable bodies self-collision
+///The DeformableMultibody demo deformable bodies self-collision
static bool g_floatingBase = true;
static float friction = 1.;
diff --git a/examples/DeformableDemo/DeformableDemo.cpp b/examples/DeformableDemo/DeformableRigid.cpp
index a3cdbf847..c26bcc7d5 100644
--- a/examples/DeformableDemo/DeformableDemo.cpp
+++ b/examples/DeformableDemo/DeformableRigid.cpp
@@ -1,17 +1,15 @@
/*
-Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans http://continuousphysics.com/Bullet/
-
-This software is provided 'as-is', without any express or implied warranty.
-In no event will the authors be held liable for any damages arising from the use of this software.
-Permission is granted to anyone to use this software for any purpose,
-including commercial applications, and to alter it and redistribute it freely,
-subject to the following restrictions:
-
-1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
-2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
-3. This notice may not be removed or altered from any source distribution.
-*/
+ Bullet Continuous Collision Detection and Physics Library
+ Copyright (c) 2016 Google Inc. http://bulletphysics.org
+ This software is provided 'as-is', without any express or implied warranty.
+ In no event will the authors be held liable for any damages arising from the use of this software.
+ Permission is granted to anyone to use this software for any purpose,
+ including commercial applications, and to alter it and redistribute it freely,
+ subject to the following restrictions:
+ 1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
+ 2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
+ 3. This notice may not be removed or altered from any source distribution.
+ */
///create 125 (5x5x5) dynamic object
#define ARRAY_SIZE_X 5
@@ -27,7 +25,7 @@ subject to the following restrictions:
#define START_POS_Y -5
#define START_POS_Z -3
-#include "DeformableDemo.h"
+#include "DeformableRigid.h"
///btBulletDynamicsCommon.h is the main Bullet include file, contains most common include files.
#include "btBulletDynamicsCommon.h"
#include "BulletSoftBody/btDeformableRigidDynamicsWorld.h"
@@ -41,17 +39,17 @@ subject to the following restrictions:
#include "../CommonInterfaces/CommonRigidBodyBase.h"
#include "../Utils/b3ResourcePath.h"
///The DeformableDemo shows the use of rolling friction.
///Spheres will come to a rest on a sloped plane using a constraint. Damping cannot achieve the same.
///Generally it is best to leave the rolling friction coefficient zero (or close to zero).
-class DeformableDemo : public CommonRigidBodyBase
+class DeformableRigid : public CommonRigidBodyBase
{
public:
- DeformableDemo(struct GUIHelperInterface* helper)
+ DeformableRigid(struct GUIHelperInterface* helper)
: CommonRigidBodyBase(helper)
{
}
- virtual ~DeformableDemo()
+ virtual ~DeformableRigid()
{
}
void initPhysics();
@@ -148,7 +146,7 @@ public:
}
};
-void DeformableDemo::initPhysics()
+void DeformableRigid::initPhysics()
{
m_guiHelper->setUpAxis(1);
@@ -246,7 +244,7 @@ void DeformableDemo::initPhysics()
m_guiHelper->autogenerateGraphicsObjects(m_dynamicsWorld);
}
-void DeformableDemo::exitPhysics()
+void DeformableRigid::exitPhysics()
{
//cleanup in the reverse order of creation/initialization
@@ -285,9 +283,9 @@ void DeformableDemo::exitPhysics()
-class CommonExampleInterface* DeformableCreateFunc(struct CommonExampleOptions& options)
+class CommonExampleInterface* DeformableRigidCreateFunc(struct CommonExampleOptions& options)
{
- return new DeformableDemo(options.m_guiHelper);
+ return new DeformableRigid(options.m_guiHelper);
}
@@ -41,17 +39,17 @@ subject to the following restrictions:
#include "../CommonInterfaces/CommonRigidBodyBase.h"
#include "../Utils/b3ResourcePath.h"
-///The DeformableDemo shows the use of rolling friction.
+///The DeformableRigid shows the use of rolling friction.
///Spheres will come to a rest on a sloped plane using a constraint. Damping cannot achieve the same.
///Generally it is best to leave the rolling friction coefficient zero (or close to zero).